A metadata plugin for isbnlib (https://pypi.python.org/pypi/isbnlib) using the service from the Deutsche National Bibliothek of Germany (https://portal.dnb.de/opac.htm) for books in German.

After install (pip install isbnlib-dnb) a new metadata provider (dnb) is available in isbnlib.
